==> lapisworks-1.5.6.7-sources.jar: com/luxof/lapisworks/actions/great/Hastenature.java <==
package com.luxof.lapisworks.actions.great;

import at.petrak.hexcasting.api.casting.OperatorUtils;
import at.petrak.hexcasting.api.casting.ParticleSpray;
import at.petrak.hexcasting.api.casting.RenderedSpell;
import at.petrak.hexcasting.api.casting.castables.SpellAction;
import at.petrak.hexcasting.api.casting.eval.CastingEnvironment;
import at.petrak.hexcasting.api.casting.eval.OperationResult;
import at.petrak.hexcasting.api.casting.eval.vm.CastingImage;
import at.petrak.hexcasting.api.casting.eval.vm.SpellContinuation;
import at.petrak.hexcasting.api.casting.iota.Iota;
import at.petrak.hexcasting.api.casting.mishaps.MishapUnenlightened;
import at.petrak.hexcasting.api.misc.MediaConstants;

import java.util.List;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2680;
import net.minecraft.class_3222;
import org.jetbrains.annotations.Nullable;

import com.luxof.lapisworks.MishapThrowerJava;

// name from chatgpt, sorry but i'm bad at naming things
// and Hastenature is a name that kicks ass you have to admit
public class Hastenature implements SpellAction {
    public int getArgc() {
        return 2;
    }

    @Override
    public SpellAction.Result execute(List<? extends Iota> args, CastingEnvironment ctx) {
        if (!ctx.isEnlightened()) { MishapThrowerJava.throwMishap(new MishapUnenlightened()); }
        class_2338 pos = OperatorUtils.getBlockPos(args, 0, getArgc());
        int times = OperatorUtils.getPositiveInt(args, 1, getArgc());
        class_2680 state = ctx.getWorld().method_8320(pos);

        return new SpellAction.Result(
            new Spell(state, pos, times),
            MediaConstants.DUST_UNIT * 5 * times,
            List.of(ParticleSpray.burst(ctx.mishapSprayPos(), 2, 15)),
            times
        );
    }

    public class Spell implements RenderedSpell {
        public final class_2680 state;
        public final class_2338 pos;
        public final int times;

        public Spell(class_2680 state, class_2338 pos, int times) {
            this.state = state;
            this.pos = pos;
            this.times = times;
        }

		@Override
		public void cast(CastingEnvironment ctx) {
            for (int i = 0; i < times; i++) {
                this.state.method_26199(ctx.getWorld(), this.pos, ctx.getWorld().field_9229);
            }
		}

        @Override
        public CastingImage cast(CastingEnvironment arg0, CastingImage arg1) {
            return RenderedSpell.DefaultImpls.cast(this, arg0, arg1);
        }
    }

    @Override
    public boolean awardsCastingStat(CastingEnvironment ctx) {
        return SpellAction.DefaultImpls.awardsCastingStat(this, ctx);
    }

    @Override
    public Result executeWithUserdata(List<? extends Iota> args, CastingEnvironment env, class_2487 userData) {
        return SpellAction.DefaultImpls.executeWithUserdata(this, args, env, userData);
    }

    @Override
    public boolean hasCastingSound(CastingEnvironment ctx) {
        return SpellAction.DefaultImpls.hasCastingSound(this, ctx);
    }

    @Override
    public OperationResult operate(CastingEnvironment arg0, CastingImage arg1, SpellContinuation arg2) {
        return SpellAction.DefaultImpls.operate(this, arg0, arg1, arg2);
    }

    @Nullable
    public static class_3222 getPlayerOrNull(CastingEnvironment ctx) {
        return ctx.getCastingEntity() != null ? (class_3222)ctx.getCastingEntity() : null;
    }
}

==> lapisworks-1.5.7-sources.jar: com/luxof/lapisworks/actions/great/Hastenature.java <==
package com.luxof.lapisworks.actions.great;

import at.petrak.hexcasting.api.casting.OperatorUtils;
import at.petrak.hexcasting.api.casting.ParticleSpray;
import at.petrak.hexcasting.api.casting.RenderedSpell;
import at.petrak.hexcasting.api.casting.castables.SpellAction;
import at.petrak.hexcasting.api.casting.eval.CastingEnvironment;
import at.petrak.hexcasting.api.casting.eval.OperationResult;
import at.petrak.hexcasting.api.casting.eval.vm.CastingImage;
import at.petrak.hexcasting.api.casting.eval.vm.SpellContinuation;
import at.petrak.hexcasting.api.casting.iota.Iota;
import at.petrak.hexcasting.api.casting.mishaps.MishapUnenlightened;
import at.petrak.hexcasting.api.misc.MediaConstants;

import java.util.List;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2680;
import net.minecraft.class_3222;
import org.jetbrains.annotations.Nullable;

import com.luxof.lapisworks.MishapThrowerJava;

// name from chatgpt, sorry but i'm bad at naming things
// and Hastenature is a name that kicks ass you have to admit
public class Hastenature implements SpellAction {
    public int getArgc() {
        return 2;
    }

    @Override
    public SpellAction.Result execute(List<? extends Iota> args, CastingEnvironment ctx) {
        if (!ctx.isEnlightened()) { MishapThrowerJava.throwMishap(new MishapUnenlightened()); }
        class_2338 pos = OperatorUtils.getBlockPos(args, 0, getArgc());
        int times = OperatorUtils.getPositiveInt(args, 1, getArgc());
        class_2680 state = ctx.getWorld().method_8320(pos);
        int buddingAmethystPenalty = state.method_27852(class_2246.field_27160) ? 3 : 1;

        return new SpellAction.Result(
            new Spell(state, pos, times),
            MediaConstants.SHARD_UNIT * buddingAmethystPenalty * times,
            List.of(ParticleSpray.burst(ctx.mishapSprayPos(), 2, 15)),
            times
        );
    }

    public class Spell implements RenderedSpell {
        public final class_2680 state;
        public final class_2338 pos;
        public final int times;

        public Spell(class_2680 state, class_2338 pos, int times) {
            this.state = state;
            this.pos = pos;
            this.times = times;
        }

		@Override
		public void cast(CastingEnvironment ctx) {
            for (int i = 0; i < times; i++) {
                this.state.method_26199(ctx.getWorld(), this.pos, ctx.getWorld().field_9229);
            }
		}

        @Override
        public CastingImage cast(CastingEnvironment arg0, CastingImage arg1) {
            return RenderedSpell.DefaultImpls.cast(this, arg0, arg1);
        }
    }

    @Override
    public boolean awardsCastingStat(CastingEnvironment ctx) {
        return SpellAction.DefaultImpls.awardsCastingStat(this, ctx);
    }

    @Override
    public Result executeWithUserdata(List<? extends Iota> args, CastingEnvironment env, class_2487 userData) {
        return SpellAction.DefaultImpls.executeWithUserdata(this, args, env, userData);
    }

    @Override
    public boolean hasCastingSound(CastingEnvironment ctx) {
        return SpellAction.DefaultImpls.hasCastingSound(this, ctx);
    }

    @Override
    public OperationResult operate(CastingEnvironment arg0, CastingImage arg1, SpellContinuation arg2) {
        return SpellAction.DefaultImpls.operate(this, arg0, arg1, arg2);
    }

    @Nullable
    public static class_3222 getPlayerOrNull(CastingEnvironment ctx) {
        return ctx.getCastingEntity() != null ? (class_3222)ctx.getCastingEntity() : null;
    }
}
